==> kubernetes-model-core-5.8.1-sources.jar: io/fabric8/kubernetes/api/model/SecretEnvSourceBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class SecretEnvSourceBuilder extends io.fabric8.kubernetes.api.model.SecretEnvSourceFluentImpl<io.fabric8.kubernetes.api.model.SecretEnvSourceBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.SecretEnvSource,io.fabric8.kubernetes.api.model.SecretEnvSourceBuilder>{
  public SecretEnvSourceBuilder() {
    this(false);
  }
  public SecretEnvSourceBuilder(java.lang.Boolean validationEnabled) {
    this(new SecretEnvSource(), validationEnabled);
  }
  public SecretEnvSourceBuilder(io.fabric8.kubernetes.api.model.SecretEnvSourceFluent<?> fluent) {
    this(fluent, false);
  }
  public SecretEnvSourceBuilder(io.fabric8.kubernetes.api.model.SecretEnvSourceFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new SecretEnvSource(), validationEnabled);
  }
  public SecretEnvSourceBuilder(io.fabric8.kubernetes.api.model.SecretEnvSourceFluent<?> fluent,io.fabric8.kubernetes.api.model.SecretEnvSource instance) {
    this(fluent, instance, false);
  }
  public SecretEnvSourceBuilder(io.fabric8.kubernetes.api.model.SecretEnvSourceFluent<?> fluent,io.fabric8.kubernetes.api.model.SecretEnvSource instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withName(instance.getName()); 
    fluent.withOptional(instance.getOptional()); 
    this.validationEnabled = validationEnabled; 
  }
  public SecretEnvSourceBuilder(io.fabric8.kubernetes.api.model.SecretEnvSource instance) {
    this(instance,false);
  }
  public SecretEnvSourceBuilder(io.fabric8.kubernetes.api.model.SecretEnvSource instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withName(instance.getName()); 
    this.withOptional(instance.getOptional()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.SecretEnvSourceFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.SecretEnvSource build() {
    SecretEnvSource buildable = new SecretEnvSource(fluent.getName(),fluent.getOptional());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SecretEnvSourceBuilder that = (SecretEnvSourceBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-core-5.12.4-sources.jar: io/fabric8/kubernetes/api/model/SecretEnvSourceBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class SecretEnvSourceBuilder extends io.fabric8.kubernetes.api.model.SecretEnvSourceFluentImpl<io.fabric8.kubernetes.api.model.SecretEnvSourceBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.SecretEnvSource,io.fabric8.kubernetes.api.model.SecretEnvSourceBuilder>{
  public SecretEnvSourceBuilder() {
    this(false);
  }
  public SecretEnvSourceBuilder(java.lang.Boolean validationEnabled) {
    this(new SecretEnvSource(), validationEnabled);
  }
  public SecretEnvSourceBuilder(io.fabric8.kubernetes.api.model.SecretEnvSourceFluent<?> fluent) {
    this(fluent, false);
  }
  public SecretEnvSourceBuilder(io.fabric8.kubernetes.api.model.SecretEnvSourceFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new SecretEnvSource(), validationEnabled);
  }
  public SecretEnvSourceBuilder(io.fabric8.kubernetes.api.model.SecretEnvSourceFluent<?> fluent,io.fabric8.kubernetes.api.model.SecretEnvSource instance) {
    this(fluent, instance, false);
  }
  public SecretEnvSourceBuilder(io.fabric8.kubernetes.api.model.SecretEnvSourceFluent<?> fluent,io.fabric8.kubernetes.api.model.SecretEnvSource instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withName(instance.getName()); 
    fluent.withOptional(instance.getOptional()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public SecretEnvSourceBuilder(io.fabric8.kubernetes.api.model.SecretEnvSource instance) {
    this(instance,false);
  }
  public SecretEnvSourceBuilder(io.fabric8.kubernetes.api.model.SecretEnvSource instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withName(instance.getName()); 
    this.withOptional(instance.getOptional()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.SecretEnvSourceFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.SecretEnvSource build() {
    SecretEnvSource buildable = new SecretEnvSource(fluent.getName(),fluent.getOptional());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SecretEnvSourceBuilder that = (SecretEnvSourceBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
